﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web.Mvc;
using KheyaOrchardGallery.Services;
using KheyaOrchardGallery.ViewModels;
using Orchard;
using Orchard.Core.Contents.Controllers;
using Orchard.Localization;
using Orchard.UI.Notify;

namespace KheyaOrchardGallery.Controllers {
    public class AdminController : Controller {
        private const string ImageGalleryName = "Kheya";
        private readonly IKheyaImageGalleryService _kheyaimageGalleryService;
        public IOrchardServices Services { get; set; }
        public Localizer T { get; set; }

        public AdminController(IOrchardServices services, IKheyaImageGalleryService kheyaimageGalleryService) {
            Services = services;
            _kheyaimageGalleryService = kheyaimageGalleryService;

            T = NullLocalizer.Instance;
        }
        public ActionResult Index() {
                return RedirectToAction("Images");
        }

        public ActionResult DeleteImage(string imageName) {
            
            try {
                _kheyaimageGalleryService.DeleteImage(ImageGalleryName, imageName);

                Services.Notifier.Information(T("Image successfully deleted"));
            }
            catch (Exception exception) {
                Services.Notifier.Error(T("Deleting image failed: {0}", exception.Message));
            }

            return RedirectToAction("Images");
        }

        [HttpGet]
        public ActionResult AddImages() {
            return View(new KheyaImageAddViewModel { AllowedFiles = _kheyaimageGalleryService.AllowedFileFormats});
        }

        [HttpPost]
        public ActionResult AddImages(KheyaImageAddViewModel viewModel) {
            viewModel.AllowedFiles = _kheyaimageGalleryService.AllowedFileFormats;
 
            if (!ModelState.IsValid)
                return View(viewModel);
 
            try {
                if (viewModel.ImageFiles == null || viewModel.ImageFiles.Count() == 0 || viewModel.ImageFiles.First() == null) {
                    ModelState.AddModelError("File", T("Select a file to upload").ToString());
 
                    return View(viewModel);
                }
 
                if (viewModel.ImageFiles.Any(file => !_kheyaimageGalleryService.IsFileAllowed(file))) {
                    ModelState.AddModelError("File", T("That file type is not allowed.").ToString());
                    return View(viewModel);
                }
 
                foreach (var file in viewModel.ImageFiles) {
                    _kheyaimageGalleryService.AddImage(ImageGalleryName, file);
                }
            }
            catch (Exception exception) {
                Services.Notifier.Error(T("Adding image failed: {0}", exception.Message));
                return View(viewModel);
            }
 
            return RedirectToAction("Images");
        }

        [HttpGet]
        public ActionResult Images() {
            var imageGallery = _kheyaimageGalleryService.GetImageGallery(ImageGalleryName);
            return View(new KheyaImageGalleryImagesViewModel
                {
                    ImageGalleryName = imageGallery.Name,
                    Images = imageGallery.Images
                });
        }
        [HttpGet]
        public ActionResult DisplayImage(string imageName) {
            var imageDirectory = _kheyaimageGalleryService.GetMediaImageFolder(ImageGalleryName, imageName);
            return View(new KheyaDisplayImage
                {
                    PublicUrl=imageDirectory,
                    ImageName=imageName
                });
        }

    }
}
